/**
 * Copyright Marcus Britanicus <marcusbritanicus@gmail.com>
 *
 * This file is a part of LibDesQ Widgets (https://gitlab.com/DesQ/libdesqui)
 * This library contains the UI classes and Plugin interfaces that are used
 * through out the DesQ Project.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * at your option, any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 **/

#include "DesQLineEdit.hpp"
#include "DesQComboBox.hpp"
#include "DesQMainWindow.hpp"

int main( int argc, char **argv ) {
    QApplication app( argc, argv );

    DesQLineEdit *le = new DesQLineEdit( "&Country:", "Enter your location here", true, nullptr );
    DesQComboBox *cb = new DesQComboBox( "&State:", {
                                             "State 1",
                                             "State 2",
                                             "State 3",
                                             "State 4",
                                             "State 5",
                                             "State 6",
                                             "State 7",
                                             "State 8",
                                             "State 9",
                                             "State 10",
                                             "State 11",
                                             "State 12",
                                             "State 13",
                                             "State 14",
                                             "State 15"
                                         }, true, nullptr );

    DesQMainWindow *mw = new DesQMainWindow();

    mw->addAction( 0, "New",        QIcon::fromTheme( "folder-new" ),          "#1" );
    mw->addAction( 0, "Folders",    QIcon::fromTheme( "folder-bookmark" ),     "#2" );
    mw->addAction( 0, "Drives",     QIcon::fromTheme( "drive-multidisk" ),     "#3" );
    mw->addAction( 0, "Terminal",   QIcon::fromTheme( "utilities-terminal" ),  "open-terminal" );

    mw->addAction( 1, "Back",       QIcon::fromTheme( "arrow-left" ),          "#0" );
    mw->addAction( 1, "New Folder", QIcon::fromTheme( "folder-new" ),          "#0" );
    mw->addAction( 1, "New File",   QIcon::fromTheme( "file-new" ),            "#0" );

    mw->addAction( 2, "Back",       QIcon::fromTheme( "arrow-left" ),          "#0" );
    mw->addAction( 2, "Home",       QIcon::fromTheme( "user-home" ),           QDir::homePath() );
    mw->addAction( 2, "Documents",  QIcon::fromTheme( "folder-documents" ),    QDir::home().filePath( "Documents" ) );
    mw->addAction( 2, "Downloads",  QIcon::fromTheme( "folder-downloads" ),    QDir::home().filePath( "Downloads" ) );
    mw->addAction( 2, "Multimedia", QIcon::fromTheme( "folder-video" ),        QDir::home().filePath( "Multimedia" ) );
    mw->addAction( 2, "FileSystem", QIcon::fromTheme( "folder-root" ),         QDir::rootPath() );
    mw->addAction( 2, "Drives",     QIcon::fromTheme( "drive-multidisk" ),     "#1" );
    mw->addAction( 2, "Trash",      QIcon::fromTheme( "user-trash" ),          "trash://" );

    mw->addAction( 3, "Back",       QIcon::fromTheme( "arrow-left" ),          "#0" );
    // mw->addSidePanelSpacer( 1 );
    mw->addAction( 3, "Debian",     QIcon::fromTheme( "drive-harddisk-root" ), "/" );
    mw->addAction( 3, "Manjaro",    QIcon::fromTheme( "drive-harddisk" ),      "/mnt/Manjaro" );
    mw->addAction( 3, "Data",       QIcon::fromTheme( "drive-harddisk" ),      "/home" );
    mw->addAction( 3, "PhD",        QIcon::fromTheme( "drive-harddisk" ),      "/home/cosmos/PhD" );
    // mw->addSidePanelStretch( 1 );

    QVBoxLayout *lyt = new QVBoxLayout();

    lyt->setSpacing( 10 );
    lyt->addWidget( le );
    lyt->addWidget( cb );

    QWidget *w = new QWidget();

    w->setLayout( lyt );
    w->show();

    mw->show();

    return app.exec();
}
